<?php

###############################################################################
# italian.php
# Traduzione italiana per GeekLog!
# Special thanks to Mischa Polivanov for his work on this project
#
# Copyright (C) 2002 quess65 webmaster@dynamikteam.net
# Copyright (C) 2005 magomarcelo magomarcelo@gmail.com magomarcelo.blogspot.com
# Copyright (C) 2010 Roccivic rouslan@placella.com
#
# Questo programma è free software; puoi ridistribuire e/o
# modificarlo sotto i termini della GNU General Public License
# come pubblicato da Free Software Foundation; dalla versione 2
# della Licenza, o (come preferisci) a qualsiasi delle versioni
# successive.
#
# Questo programma è distribuito con la speranza sia utile,
# ma SENZA NESSUNA GARANZIA; senza qualsiasi garanzia implicita di
# COMMERCIABILITA o USO PER SCOPI PARTICOLARI. Vedi la
# GNU General Public License per ulteriori dettagli.
#
# Dovresti aver ricevuto una copia della GNU General Public License
# insieme a questo programma; altrimenti scrivi a Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'UTF-8';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Inviato da:',
    2 => 'continua ->',
    3 => 'commenti',
    4 => 'Modifica',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Funzioni Ammin:',
    10 => 'Inserimenti',
    11 => 'Articoli',
    12 => 'Blocchi',
    13 => 'Argomenti',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Utenti',
    18 => 'SQL Query',
    19 => 'Esci',
    20 => 'Informazioni utente:',
    21 => 'Nome Utente',
    22 => 'ID Utente',
    23 => 'Livello di sicurezza',
    24 => 'Anonimo',
    25 => 'Rispondi',
    26 => 'I seguenti commenti sono proprietá di chi li ha inviati. Questo sito non é responsabile dei contenuti degli stessi.',
    27 => 'Inserimenti piú recenti',
    28 => 'Elimina',
    29 => 'Nessun commento.',
    30 => 'Articoli vecchi',
    31 => 'Tag HTML permessi:',
    32 => 'Errore, nome utente non valido',
    33 => 'Errore, non é stato possibile scrivere nel file di log',
    34 => 'Errore',
    35 => 'Esci',
    36 => 'su',
    37 => 'Nessun articolo dagli utenti',
    38 => 'Pubblicazione del Contenuto',
    39 => 'Aggiorna',
    40 => '',
    41 => 'Utenti non registrati',
    42 => 'Inviato da:',
    43 => 'Rispondi a Questo',
    44 => 'Relativo',
    45 => 'Numero Errore MySQL',
    46 => 'Messaggio Errore MySQL',
    47 => 'Funzioni per Utenti',
    48 => 'Il Mio Account',
    49 => 'Preferenze',
    50 => 'Errore nella domanda SQL',
    51 => 'aiuto',
    52 => 'Nuovo',
    53 => 'Home Ammin.',
    54 => 'Impossibile aprire il file.',
    55 => 'Errore su',
    56 => 'Vota',
    57 => 'Password',
    58 => 'Entra',
    59 => "Non hai ancora un account? Iscriviti come un <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Nuovo Utente</a>",
    60 => 'Inserisci un commento',
    61 => 'Crea un nuovo Account',
    62 => 'parole',
    63 => 'Preferenze Commenti',
    64 => 'Invia l\'articolo ad un amico',
    65 => 'Visualizza la versione stampabile',
    66 => '',
    67 => 'Benvenuto su ',
    68 => 'Home',
    69 => 'Contatto',
    70 => 'Cerca',
    71 => 'Scrivi',
    72 => 'Risorse Web',
    73 => '',
    74 => '',
    75 => 'Ricerca Avanzata',
    76 => 'Statistiche del Sito',
    77 => 'Estensioni',
    78 => '',
    79 => 'Novitá',
    80 => 'articoli nelle ultime',
    81 => 'articolo nelle ultime',
    82 => 'ore',
    83 => 'Commenti',
    84 => '',
    85 => '<br' . XHTML . '>nelle ultime 48 ore',
    86 => 'Nessun nuovo commento',
    87 => '<br' . XHTML . '>nelle ultime 2 settimane',
    88 => '',
    89 => '',
    90 => 'Home',
    91 => 'Pagina creata in',
    92 => 'secondi',
    93 => 'Copyright',
    94 => 'Tutti i marchi e diritti d\'autore su questa pagina appartengono ai rispettivi proprietari.',
    95 => 'Powered by',
    96 => 'Gruppi',
    97 => 'Lista parole',
    98 => 'Plug-in',
    99 => 'Articoli',
    100 => 'Nessun nuovo articolo',
    101 => '',
    102 => '',
    103 => 'Backup DB',
    104 => 'da',
    105 => 'Invio E-mail',
    106 => 'Visualizzazioni:',
    107 => 'Test Versione GeekLog',
    108 => 'Svuota Cache',
    109 => 'Segnala abuso',
    110 => 'Segnala questo inserimento all\'ammin. del sito',
    111 => '',
    112 => 'Utenti Registrati',
    113 => 'Documentazione',
    114 => 'Trackbacks',
    115 => 'No new trackback comments',
    116 => 'Trackback',
    117 => 'Cartella',
    118 => 'Continua a legge sulla pagina successiva:',
    119 => "Hai dimenticato la tua <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">password</a>?",
    120 => 'Collegamento permanente a questo commento',
    121 => 'Commenti (%d)',
    122 => 'Trackback (%d)',
    123 => 'HTML é permesso',
    124 => 'Clicca per cancellare tutti gli oggetti selezionati',
    125 => 'Sei sicuro che vuoi Cancellare tutti gli oggetti selezionati?',
    126 => 'Seleziona o deseleziona tutti gli oggetti',
    127 => 'Collegamento permanente',
    128 => 'Accedi con OpenID:',
    129 => 'Configurazione',
    130 => 'Servizi Web'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Inserisci un commento',
    2 => 'Modo di Inserimento',
    3 => 'Esci',
    4 => 'Crea un Account',
    5 => 'Nome Utente',
    6 => 'Per poter inserire un commento su questo sito é necessario loggarsi. Se non hai ancora un account puoi usare il form sottostante per crearne uno.',
    7 => 'Il tuo ultimo commento risale a ',
    8 => " secondi fá  Questo sito richiede che attendi {$_CONF['commentspeedlimit']} secondi tra gli inserimenti dei commenti.",
    9 => 'Commento',
    10 => 'Invia Segnalazione',
    11 => 'Inserisci Commento',
    12 => 'Per poter inserire un commento é necessario riempire tutti i campi.',
    13 => 'Le tue info',
    14 => 'Anteprima',
    15 => 'Segnala questo inserimento',
    16 => 'Titolo',
    17 => 'Errore',
    18 => 'Materiale Importante',
    19 => 'Per favore prova a mantenere questo inserimento in cima agli argomenti.',
    20 => 'Prova a rispondere ad un commento di un altro utente anziché aprire un nuovo inserimento.',
    21 => 'Leggi i messaggi degli altri utenti prima di inviare il tuo in maniera da evitare messaggi doppi.',
    22 => 'Usa un soggetto che descriva il contenuto del messaggio.',
    23 => 'Il tuo indirizzo e-mail NON sará reso pubblico.',
    24 => 'Utente Anonimo',
    25 => 'Sei sicuro di voler segnalare questo inserimento all\'amminstratore del sito?',
    26 => '%s ha segnalato come abuso il seguente commento:',
    27 => 'Segnalazione abuso',
    28 => 'Anteprima dei cambiamenti',
    29 => 'Inoltra i cambiamenti',
    30 => 'Modificato il',
    31 => 'da',
    32 => 'Modifica del Commento',
    33 => 'Editing a Comment Submission',
    34 => 'Anteprima delle modifiche dell\'Inserimento',
    35 => 'Salva i cambiamenti in coda',
    36 => 'Notificami di nuove risposte',
    37 => 'Nuova risposta al commento',
    38 => 'Il tuo commento ha ricevuto una risposta \'%s\'.',
    39 => 'Puoi vedere il commento al seguente indirizzo:',
    40 => 'Se non vuoi ricevere ulteriori notificazioni di risposte, clicca sul seguente collegamento:',
    41 => 'Ciao %s,',
    42 => 'Annullare l\'Iscrizione',
    43 => 'Annullare l\'Iscrizione dalle notifiche di reisposte',
    44 => 'Il tuo nome'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Profilo Utente di',
    2 => 'Nome Utente',
    3 => 'Nome Completo',
    4 => 'Nuova Password',
    5 => 'E-mail',
    6 => 'Homepage',
    7 => 'Bio',
    8 => 'Chiave PGP',
    9 => 'Registra Informazioni',
    10 => 'Ultimi 10 commenti dell\'utente',
    11 => 'Nessun commento dell\'utente',
    12 => 'Preferenze dell\'utente',
    13 => 'E-mail Digest Notturno',
    14 => 'Questa password é generata in maniera casuale. Si raccomanda di cambiare la password al piú presto. Per cambiare la password, entra nel sito, poi clicca su Informazioni Account dal menú utente.',
    15 => "Il tuo account su {$_CONF['site_name']} é stato creato correttamente. Per entrare nel sito usa le informazioni sottostanti. Si consiglia di registrare la mail per non perdere i dati dell'account.",
    16 => 'Informazioni del tuo account',
    17 => 'L\'Account non esiste',
    18 => 'L\'indirizzo e-mail fornito non é un indirizzo valido',
    19 => 'Il nome utente o l\'indirizzo e-mail fornito é giá esistente',
    20 => 'L\'indirizzo e-mail fornito non é un indirizzo valido',
    21 => 'Errore',
    22 => "Registrati su {$_CONF['site_name']}!",
    23 => "<div align=\"justify\">La creazione di un Account Utente dá la possibilitá di partecipare alla costruzione di {$_CONF['site_name']} e ti permette di inviare commenti e articoli realizzati da te. Senza un Account sarai in grado di inserire solo come Anonimo. Prego nota che il tuo indirizzo e-mail non sará <b><i>mai</i></b> pubblicamente visualizzata su questo sito.</div>",
    24 => 'La tua password sará inviata all\'indirizzo da te inserito.',
    25 => 'Hai dimenticato la tua password?',
    26 => 'Inserisci il tuo nome utente <em>o</em> l\'indirizzo e-mail usato per registrarti e fai clic su "Invia Password via E-mail". Le istruzioni su come impostare una nuova password ti saranno inviate all\'indirizzo con il quale ti sei registrato.',
    27 => 'Registrati Ora!',
    28 => 'Invia Password via E-mail',
    29 => 'uscito da',
    30 => 'entrato da',
    31 => 'La funzione da te selezionata richiede la tua autenticazione',
    32 => 'Firma',
    33 => 'Mai disponibile pubblicamente',
    34 => 'Questo é il tuo vero nome',
    35 => 'Inserisci una password per cambiarla',
    36 => 'Comincia con http://',
    37 => 'Applicato ai tuoi commenti',
    38 => 'Informazioni Aggiuntive! Tutti possono leggere questo',
    39 => 'La tua chiave pubblica PGP key da condividere',
    40 => 'Nascondi Icone Argomenti',
    41 => 'Disponibile a Moderare',
    42 => 'Formato Data',
    43 => 'Numero Massimo di Articoli',
    44 => 'Nascondi box',
    45 => 'Mostra preferenze per',
    46 => 'Oggetti esclusi per',
    47 => 'Box configurazioni di notizie per',
    48 => 'Articoli',
    49 => 'Nascondi icone in articoli',
    50 => 'Deseleziona se non sei interessato',
    51 => 'Solo le notizie',
    52 => 'Per definizione é',
    53 => 'Ricevi gli articoli giornalieri ogni notte',
    54 => 'Seleziona l\'opzione per gli articoli e gli autori che non vuoi vedere.',
    55 => 'Se lasci tutto non selezionato, significa che vuoi la selezione predefinita. Se inizi a selezionare i box, ricordati di impostare tutti quelli desiderati siccome la configurazione di predefinita verrá ignorata. La selezione predefinita é indicata in grassetto.',
    56 => 'Autori',
    57 => 'Modalitá Visualizzazione',
    58 => 'Ordinamento',
    59 => 'Limiti per i commenti',
    60 => 'Come preferisci siano visualizzati i tuoi commenti?',
    61 => 'Prima i piú recenti o i meno recenti?',
    62 => 'Il numero predefinito é 100',
    63 => "La tua password é stata inviata e dovrebbe arrivarti a momenti. Prego segui le istruzioni nel messaggio e grazie per la tua partecipazione a {$_CONF['site_name']}",
    64 => 'Preferenze Commenti per',
    65 => 'Prova a entrare di nuovo',
    66 => 'É possibile che hai sbagliato le tue credenziali di accesso. Prego riprova di nuovo.',
    67 => 'Membro Dal',
    68 => 'Ricordami Per',
    69 => 'Per quanto tempo vuoi essere ricordato dopo l\'ingresso nel sito?',
    70 => "Personalizza lo stile e il contenuto di {$_CONF['site_name']}",
    71 => "Una delle funzionalitá di {$_CONF['site_name']} é che puoi personalizzarne il contenuto e lo stile.  Per utilizzare questa funzione devi prima <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">registrarti</a> a {$_CONF['site_name']}. Sei giá un membro? Allora usa il form di accesso che trovi alla tua sinistra per entrare!",
    72 => 'Stile',
    73 => 'Lingua',
    74 => 'Cambia lo stile di visualizzazione di questo sito!',
    75 => 'Argomenti da inviare via e-mail per',
    76 => 'Se selezioni un argomento dalla lista sottostante riceverai via e-mail ogni nuovo articolo associato all\'argomento alla fine della giornata. Seleziona solo gli argomenti che ti interessano!',
    77 => 'Foto',
    78 => 'Aggiungi una foto di te!',
    79 => 'Seleziona quí per eliminare questa immagine',
    80 => 'Entra',
    81 => 'Invia E-mail',
    82 => 'Ultimi 10 articoli per utente',
    83 => 'Statistiche di inserimento per utente',
    84 => 'Numero totale di articoli:',
    85 => 'Numero totale di commenti:',
    86 => 'Trova tutti gli inserimenti di',
    87 => 'Il tuo nome utente',
    88 => "Qualcuno (probabilmente tu) ha richiesto una nuova password per il tuo account \"%s\" su {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nSe vuoi veramente eseguire questa azione, prego clicca sul seguente collegamento:\n\n",
    89 => "Se non vuoi eseguire questa operazione, semplicemente ignora questo messaggio e la richiesta sará scartata (la tua password non verrá modificata).\n\n",
    90 => 'Puoi inserire una nuova password per il tuo account sotto. Prego nota che la tua vecchia password é ancora valida fino a che non invii questo form.',
    91 => 'Imposta Nuova Password',
    92 => 'Inserisci Nuova Password',
    93 => 'La tua ultima richiesta di una nuova password é stata eseguita %d secondi fá. Questo sito richiede almeno %d secondi tra una richiesta e l\'altra.',
    94 => 'elimina Account "%s"',
    95 => 'Clicca sul bottone "elimina account" sottostante per eliminare il tuo account dal nostro database. Prego nota che qualsiasi articolo e commento da te inserito con questo account <strong>non</strong> verrá eliminato, ma verrá visualizzato come inviato da un "Anonimo".',
    96 => 'Elimina account',
    97 => 'Conferma Eliminazione Account',
    98 => 'Sei sicuro di voler eliminare il tuo account? Cosí facendo, non sarai piú in grado di entrare ancora in questo sito (fintantoché non crei un nuovo account). Se sei sicuro, fai clic su "Elimina account" di nuovo nel form sottostante.',
    99 => 'Opzioni della Privacy per',
    100 => 'E-mail dall\'Amministratore',
    101 => 'Permetti E-mail dagli Amministratori del Sito',
    102 => 'E-mail dagli Utenti',
    103 => 'Permetti E-mail da altri Utenti',
    104 => 'Visualizza Stato in Linea',
    105 => 'Mostrami nel blocco degli utenti in linea',
    106 => 'Localitá',
    107 => 'Mostra nel tuo profilo pubblico',
    108 => 'Conferma nuova password',
    109 => 'Conferma la Nuova password qui',
    110 => 'Password attuale',
    111 => 'Prego entra la password attuale',
    112 => 'Hai superato il numero massimo di tentativi d\'accesso. Prego riprova piú tardi.',
    113 => 'Tentativo di accesso fallito',
    114 => 'Account Disabilitato',
    115 => 'Il suo account é stato disabilitato, non hai piú diritto di accesso. Prego contatta l\'amministratore.',
    116 => 'Account in attesa di verificazione',
    117 => 'Il suo account é al momento in attesa di verificazione da un amministratore. Non sarai in grado di entrare finché il suo account sará approvato.',
    118 => "Il suo account presso {$_CONF['site_name']} é stato approvato da un amministratore. Poui ora accedere il sito all indirizzo sottostante utilizzando il tuo nome utente (<username>) e password che ti sono stati inviati.",
    119 => 'Se hai dimenticato la tua password, puoi richedere una nuova a questo indirizzo:',
    120 => 'Account Attivato',
    121 => 'Servizio',
    122 => 'Scusa, ma la registrazione di nuovi account é stata disabilitata',
    123 => "Sei un <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">nuovo utente</a>?",
    124 => 'Conferma E-mail',
    125 => 'Devi immettere lo stesso indirizzo e-mail in entrambi i campi!',
    126 => 'Prego ripeti per confermare',
    127 => 'Per cambiare queste impostazioni, bisogna che confermi la tua password attuale.',
    128 => 'Il tuo Nome',
    129 => 'Password ed E-mail',
    130 => 'A Proposito di Te',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Visualizzazione commenti',
    134 => 'Opzioni Commenti',
    135 => '<li>Il modo predefinito per mostrare i commenti</li><li>Ordine predefinito per mostrare i commenti</li><li>Scegli il numero massimo di commenti da mostrare - il predefinito é 100</li>',
    136 => 'Escludi Articoli ed Autori',
    137 => 'Filtra il contenuto degli articoli',
    138 => 'Impostazioni varie',
    139 => 'Schema e Lingua',
    140 => '<li>Nessun icona per Argomenti. Se selezionato, non mostrera icone per argomenti.</li><li>Nussun Box. Se selezionato, verranno solo mostrati il Menu Ammin, Menu Utenti e Argomenti</li><li>Imposta il numero massimo di articoli da mostrare per pagina</li><li>Seleziona il tuo stile, fuso orario e formato desiderato della data</li>',
    141 => 'Impostazioni di Privacy',
    142 => 'Le impostazioni predefinite permettono altri utenti ed ammistratori di mandare e-mail agli utenti del sito e mostrare il suo stato online. Deselezione queste opzioni per proteggere la tua privacy.',
    143 => 'Filtra il Contenuto dei Blocchi',
    144 => 'Mostra e Nascondi i box',
    145 => 'Il tuo profilo pubblico',
    146 => 'Password ed e-mail',
    147 => 'Modifica la tua password, email ed impostazione di accesso automatico. Dovrai inserirre la stessa password o e-mail due volte per confermare.',
    148 => 'Informazioni Utente',
    149 => 'Modifica la tua inforazione utente pubblica.<li>La firma verrá inclusa con i commenti o post nei forum che fai.</li><li>La BIO é un piccolo riassunto su di té da condividere.</li><li>Condividi la tua chiave PGP</li>',
    150 => 'Attenzione: Javascript é raccomandato per funzionalitá avanzate',
    156 => 'Cancella Account',
    157 => 'Cancella Opzione',
    158 => 'Fuso Orario',
    159 => 'Questa email é stata generata automaticamente. La preghiamo di non rispondere.',
    160 => '(massimo %d x %d pixel, %d byte; %s)',
    161 => 'sará ridimensionato',
    162 => 'non sará ridimensionato',
    163 => 'Re-Autenticazione Fallita',
    164 => 'Hai superato il numero di tentativi consentiti per la re-autenticazione. Quest\'azione é stata annullata e le tue recenti modifiche sono state perse.',
    165 => 'Usa l\'Editor Avanzato'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Anteprima',
    'pe_namepass' => 'Nome utente e Password',
    'pe_userinfo' => 'A Proposito di Te',
    'pe_layout' => 'Schema e Lingua',
    'pe_content' => 'Contenuto',
    'pe_privacy' => 'Privacy'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Non ci sono Notizie da visualizzare',
    2 => '<br' . XHTML . '>Non ci sono nuovi articoli da visualizzare. Questo perché o non ci sono nuovi articoli relativi a questo argomento o le tue preferenze utente sono troppo restrittive ',
    3 => 'per l\'argomento <b>%s</b>',
    4 => 'Articolo del giorno',
    5 => 'Successivo',
    6 => 'Precedente',
    7 => 'Primo',
    8 => 'Ultimo'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'C\'é stato un errore nell\'invio del tuo messaggio. Prego riprova un\'altra volta.',
    2 => 'Messaggio inviato correttamente.',
    3 => 'Prego assicurati di usare un indirizzo e-mail valido nel campo Rispondi a:.',
    4 => 'Prego compila i campi Tuo Nome, Rispondi a:,Soggetto e Messaggio',
    5 => 'Errore: Nessun Utente.',
    6 => 'C\'é stato un errore.',
    7 => 'Profilo Utente per',
    8 => 'Nome Utente',
    9 => 'URL Utente',
    10 => 'Invia mail a',
    11 => 'Tuo Nome:',
    12 => 'Rispondi a:',
    13 => 'Soggetto:',
    14 => 'Messaggio:',
    15 => 'L\'HTML non sará tradotto.',
    16 => 'Invia Messaggio',
    17 => 'Spedisci l\'Articolo a un amico',
    18 => 'A Nome',
    19 => 'A Indirizzo E-mail',
    20 => 'Da Nome',
    21 => 'Da Indirizzo E-mail',
    22 => 'Tutti i campi sono richiesti',
    23 => "Questa e-mail ti é stata inviata da %s a %s perché pensa possa interessarti questo articolo proveniente da {$_CONF['site_url']}.  Questa non é SPAM e il tuo indirizzo e-mail utilizzato in questa operazione non verrá registrato nella lista per un successivo uso.",
    24 => 'Commento su questo articolo a',
    25 => 'Devi essere un utente registrato per accedere a questa funzione. Identificandoti come utente ci aiuti a prevenire eventuali abusi sul sistema',
    26 => 'Questo form ti permette di inviare una e-mail all\'utente selezionato.  Tutti i campi sono richiesti.',
    27 => 'Messaggio breve',
    28 => '%s scrive: ',
    29 => "Questo è la newsletter quotidiana per {$_CONF['site_name']} del ",
    30 => ' - Newsletter quotidiana del ',
    31 => 'Titolo',
    32 => 'Data',
    33 => 'Leggi l\'articolo completo su',
    34 => 'Fine del messaggio',
    35 => 'Scusa, ma l\'utente preferisce non ricevere e-mail.',
    36 => 'Copia:',
    37 => 'Inviami una copia di questa e-mail',
    38 => "Questa é una copia dell'e-mail che hai inviato a %s da <{$_CONF['site_url']}>:",
    39 => 'Your last message was ',
    40 => " seconds ago.  This site requires at least {$_CONF['speedlimit']} seconds between sending messages"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Ricerca Avanzata',
    2 => 'Parole chiave',
    3 => 'Argomenti',
    4 => 'Tutti',
    5 => 'Tipo',
    6 => 'Articoli',
    7 => 'Commenti',
    8 => 'Autori',
    9 => 'Tutti',
    10 => 'Ricerca',
    11 => 'Risultati Ricerca',
    12 => 'risultati',
    13 => 'Risultati Ricerca: Nessun risultato',
    14 => 'Non ci sono risultati per la tua ricerca su',
    15 => 'Prego riprova.',
    16 => 'Titolo',
    17 => 'Data',
    18 => 'Autore',
    19 => "Ricerca nell'intero database di articoli correnti e passati di {$_CONF['site_name']}",
    20 => 'Data',
    21 => 'a',
    22 => '(Formato Data YYYY-MM-DD)',
    23 => 'Visite',
    24 => 'Trovato %d risultati',
    25 => 'Ricerca effettuata per',
    26 => 'oggetti in',
    27 => 'secondi',
    28 => 'Nessun articolo o commento trovato per la tua ricerca',
    29 => 'Risultato Articoli e Commenti',
    30 => '',
    31 => 'Questo plug-in non restituisce nessun risultato',
    32 => '',
    33 => 'URL',
    34 => 'Localitá',
    35 => 'Tutti i giorni',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'La tua stringa di ricerca deve avere almeno 3 caratteri.',
    42 => 'Prego usa una data formattata come YYYY-MM-DD (anno-mese-giorno).',
    43 => 'frase esatta',
    44 => 'tutte queste parole',
    45 => 'qualsiasi di queste parole',
    46 => 'Prossimo',
    47 => 'Precedente',
    48 => 'Autore',
    49 => 'Data',
    50 => 'Visite',
    51 => '',
    52 => 'Localitá',
    53 => 'Risultato Articoli',
    54 => 'Risultato Commenti',
    55 => 'la stringa',
    56 => 'E',
    57 => 'O',
    58 => 'Piú risultati &gt;&gt;',
    59 => 'Risultati',
    60 => 'per pagina',
    61 => 'Raffina la ricerca',
    62 => '#',
    63 => 'Descrizione',
    64 => '%1$d - %2$d di %3$d risultati',
    65 => 'Articolo',
    66 => 'Commento',
    67 => 'Mostra %d Risultati',
    68 => 'Ordina Per',
    69 => 'Solo titoli',
    70 => 'Non disponibile ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Statistiche Sito',
    2 => 'Visite Totali nel sistema',
    3 => 'Articoli(Commenti) nel sistema',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Top 10 Articoli Visitati',
    8 => 'Titolo Articolo',
    9 => 'Visite',
    10 => 'Sembra non ci siano articoli in questo sito.',
    11 => 'Top 10 Articoli Commentati',
    12 => 'Commenti',
    13 => 'Sembra non ci siano articoli disponibili in questo sito o nessuno ha ancora inserito un commento sullo stesso.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Top 10 Articoli Inseriti',
    23 => 'E-mail',
    24 => 'Sembra che nessuno abbia ancora inviato un articolo su questo sito',
    25 => 'Top 10 Articoli Trackback Commentati',
    26 => 'Nessun commento trackback.',
    27 => 'Numero di utenti attivi',
    28 => '',
    29 => '',
    30 => 'Visite',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Relativo a..',
    2 => 'Invia l\'Articolo a un amico',
    3 => 'Articolo in Formato Stampabile',
    4 => 'Opzioni',
    5 => '',
    6 => 'Sottoscrivi a \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Per inserire un %s é richiesto che tu ti autentifichi come utente.',
    2 => 'Entra',
    3 => 'Nuovo Utente',
    4 => '',
    5 => '',
    6 => 'Invia un Articolo',
    7 => 'Autenticazione Richiesta',
    8 => 'Invia',
    9 => 'Per l\'inserimento di informazioni da utilizzare in questo sito ti chiediamo di seguire i seguenti consigli...<ul><li>Inserisci tutti i campi, sono tutti richiesti<li>Fornisci informazioni complete e accurate<li>Controlla bene tutti gli URLs</ul>',
    10 => 'Titolo',
    11 => '',
    12 => 'Data Inizio',
    13 => 'Data Fine',
    14 => 'Localitá',
    15 => 'Descrizione',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Leggi prima',
    20 => '',
    21 => '',
    22 => 'Errore: Campi Mancanti',
    23 => 'Prego compila tutti i campi del form. Tutti i campi sono richiesti.',
    24 => 'Inserimento Registrato',
    25 => 'Il tuo %s inserimento é stato registrato correttamente.',
    26 => 'Limite Velocitá',
    27 => 'Nome Utente',
    28 => 'Argomento',
    29 => 'Articolo',
    30 => 'Il tuo ultimo inserimento risale a ',
    31 => " secondi fá.  Questo sito richiede almeno {$_CONF['speedlimit']} secondi fra un inserimento e l'altro",
    32 => 'Anteprima',
    33 => 'Anteprima Articolo',
    34 => 'Esci',
    35 => 'I tag HTML non sono consentiti',
    36 => 'Modalitá Inserimento',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Indirizzo 1',
    45 => 'Indirizzo 2',
    46 => 'Cittá Paese',
    47 => 'Stato',
    48 => 'C.A.P.',
    49 => '',
    50 => '',
    51 => 'Localitá',
    52 => 'Elimina',
    53 => 'Crea un Account',
    54 => 'Introduzione della storia',
    55 => 'Corpo della storia'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Autenticazione Richiesta',
    2 => 'Negato! Informazioni d\'accesso non corrette',
    3 => 'Password non valida per l\'utente',
    4 => 'Nome Utente:',
    5 => 'Password:',
    6 => 'Tutti gli accessi alle parti amministrative di questo sito sono registrate e controllate.<br' . XHTML . '>Questa pagina e per il solo personale autorizzato.',
    7 => 'Entra'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Permessi di amministrazione insufficienti',
    2 => 'Non hai i permessi necessari per modificare questo blocco.',
    3 => 'Editor Blocchi',
    4 => 'Si é verificato un problema nella lettura di questo feed (vedi error.log per dettagli).',
    5 => '',
    6 => '',
    7 => 'Tutti',
    8 => 'Livello Sicurezza Blocco',
    9 => 'Ordine Blocco',
    10 => '',
    11 => 'Blocco Portale',
    12 => 'Blocco Normale',
    13 => 'Opzioni Blocco Portale',
    14 => 'RDF URL',
    15 => 'Ultimo Agg. RDF',
    16 => 'Opzioni Blocco Normale',
    17 => 'Contenuto Blocco',
    18 => 'Prego completa i campi Titolo Blocco, Livello Sicurezza e Contenuto',
    19 => 'Manager Blocchi',
    20 => '',
    21 => 'SecLev Blocco',
    22 => '',
    23 => 'Ordine Blocco',
    24 => '',
    25 => 'Per modificare o eliminare un blocco, fai clic sul blocco selezionato. <br' . XHTML . '>Per creare un nuovo blocco fai clic su [ Nuovo Blocco ] sopra.',
    26 => 'Impaginazione Blocco',
    27 => 'Blocco PHP',
    28 => 'Opzioni Blocco PHP',
    29 => 'Funzione Blocco',
    30 => 'Se desideri avere un blocco che usi il codice PHP, inserisci il nome della funzione sotto.  Il nome della tua funzione deve iniziare con il prefisso "phpblock_" (es. phpblock_getweather).  Se non ha questo prefisso, la tua funzione NON verrá richiamata.  Questo per evitare che altre persone possano hackerare la vostra installazione di Geeklog inserendo funzioni di chiamate a codice arbitrario che possa danneggiare il vostro sistema.  Assicuratevi di inserire le parentesi vuote "()" dopo il vostro nome della funzione.  <br' . XHTML . '><br' . XHTML . '>Per ultimo, é raccomandabile mettere tutto il codice del Blocco in /path/to/geeklog/system/lib-custom.php.  <br' . XHTML . '><b>Questo permette di registrare il tuo codice nel caso di aggiornamenti di Geeklog.</b>',
    31 => 'Errore nel Blocco PHP.  La Funzione, %s, non esiste.',
    32 => 'Errore Campo(i) Mancante(i)',
    33 => 'Devi inserire la URL del file .rdf per il blocco portale',
    34 => 'Devi inserire il titolo e la funzione per il blocco PHP',
    35 => 'Devi inserire il titolo e il contenuto del blocco Normale',
    36 => 'Devi inserire il contenuto per il layout blocco',
    37 => 'Errato nome della funzione Blocco PHP',
    38 => 'La funzione per il Blocco PHP deve avere il prefisso \'phpblock_\' (es. phpblock_getweather).  Il prefisso \'phpblock_\' é richiesto per ragioni di sicurezza in particolare per prevenire le esecuzioni di codice arbitrario.',
    39 => 'Lato',
    40 => 'Sinistro',
    41 => 'Destro',
    42 => 'Devi inserire l\'ordine del blocco e il livello di sicurezza per i blocchi di default di Geeklog',
    43 => 'Solo in Homepage',
    44 => '',
    45 => "Stai tentando di accedere a un blocco del quale non hai i permessi di modifica.  Questo tentativo sará registrato. Prego <a href=\"{$_CONF['site_admin_url']}/block.php\">ritorna alla schermata di amministrazione</a>.",
    46 => 'Nuovo Blocco',
    47 => '',
    48 => 'Nome Blocco',
    49 => ' (nessun spazio e deve essere univoco)',
    50 => 'Il Nome del Blocco non puo essere vuoto',
    51 => 'includi http://',
    52 => 'Se lasci in bianco questo spazio non verrá visualizzata la icona di Help per questo blocco',
    53 => 'Abilitato',
    54 => 'Registra',
    55 => 'Annulla',
    56 => 'Elimina',
    57 => 'Sposta Blocco In Basso',
    58 => 'Sposta Blocco in Alto',
    59 => 'Sposta blocco sul lato destro',
    60 => 'Sposta blocco sul lato sinistro',
    61 => 'Nessun titolo',
    62 => 'Limito per Articoli',
    63 => 'Titolo del blocco non consentito',
    64 => 'Il tuo titolo non puo essera vuoto ed HTML non &egrave consentito!',
    65 => 'Ordina',
    66 => 'Autotag',
    67 => 'Seleziona per consentire "autotag"',
    68 => 'Il flusso per questo portale é troppo lungo per mostrarlo. Scegli il numero massimo per articoli da importare nel blocco nella configurazione dei blocchi, o un numero massimo globale nella configurazione di Geeklog.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Articolo Precedente',
    2 => 'Prossimo Articolo',
    3 => 'Modalitá',
    4 => 'Modo Ins.',
    5 => 'Editor Articoli',
    6 => 'Non ci sono articoli nel sistema',
    7 => 'Autore',
    8 => 'Registra',
    9 => 'Anteprima',
    10 => 'Annulla',
    11 => 'Elimina',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Data',
    16 => 'Testo Intro',
    17 => 'Corpo',
    18 => 'Visite',
    19 => 'Commenti',
    20 => 'Ping',
    21 => 'Invia Ping',
    22 => 'Lista Articoli',
    23 => 'Per modificare o eliminare un articolo, fai clic sul numero dell\'articolo. <br' . XHTML . '>Per visualizzare un articolo, fai clic sul titolo dell\'articolo desiderato. <br' . XHTML . '>Per creare un nuovo articolo fai clic su [ Nuovo Articolo ] sopra.',
    24 => 'L\'ID da te scelto per questo articolo é giá in uso. Prego scegli un altro ID.',
    25 => 'Si é verificato un errore durante il salvataggio dell\'articolo',
    26 => 'Anteprima Articolo',
    27 => 'Se usi [unscaledX] invece di [imageX],l\'immagine varrá inserita utilizzando le dimensioni originali.',
    28 => '<p><b>ANTEPRIMA</b>: L\'Anteprima di un articolo con immagini allegate risulta piú agevole da realizzare registrandolo come bozza AL POSTO di fare clic sul bottone anteprima. Usare il bottone anteprima solo con immagini che non sono allegate.',
    29 => 'Trackback',
    30 => 'Errore nel caricamento File',
    31 => 'Prego compila i campi di testo Titolo e Intro',
    32 => 'Evidenz.',
    33 => 'Ci puó essere solo un articolo Evidenziato',
    34 => 'Bozza',
    35 => 'Si',
    36 => 'No',
    37 => 'Altro da',
    38 => 'Altro su',
    39 => 'E-mail',
    40 => '',
    41 => "Stai tentando di accedere a un articolo dove non hai i permessi di accesso. Questo tentativo sará tracciato. Puoi visualizzare l\articolo in sola lettura sotto. Prego <a href=\"{$_CONF['site_admin_url']}/story.php\">ritorna alla schermata amministrazione articoli</a> una volta terminato.",
    42 => "Stai tentando di accedere a un articolo dove non hai i permessi di accesso. Questo tentativo sará tracciato. Prego <a href=\"{$_CONF['site_admin_url']}/story.php\">ritorna alla schermata amministrazione articoli</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>NOTA:</b> se modifichi questa data postadatandola, questo articolo non sará pubblicato fino a suddetta data.  Questo significa inoltre che l\'articolo non sará incluso nel tuo <em>RDF headline</em> e verrá ignorato dalla ricerca e dalle statistiche.',
    47 => 'Immagini',
    48 => 'image',
    49 => 'right',
    50 => 'left',
    51 => 'Per aggiungere una delle immagini in allegato a questo articolo devi inserire del codice di testo speciale. Questo codice speciale é [imageX], [imageX_right] o [imageX_left] dove X é il numero della immagine allegata.  <br' . XHTML . '>NOTA: Devi utilizzare le immagini allegate. Altrimenti non sarai in grado di registrare il tuo articolo.<br' . XHTML . '>',
    52 => '',
    53 => 'non é utilizzata.  Devi includere questa immagine nell\'intro o nel corpo per poter registrare le tue modifiche',
    54 => 'Immagini in Allegato Non Usate',
    55 => 'Si sono verificati i seguenti errori durante la registrazione del tuo articolo. Prego correggi gli errori prima di registrarlo',
    56 => 'Mostra Icona Argomento',
    57 => 'Mostra Immagine non ridimensionata',
    58 => 'Gestione Articoli',
    59 => 'Opzione',
    60 => '',
    61 => 'Archivazione Automatica',
    62 => 'Eliminazione Automatica',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Espandi lo spazio di modifica contenuto',
    68 => 'Riduci lo spazio di modifica contenuto',
    69 => 'Pubblica la data della storia',
    70 => 'Selezione di barre degli strumenti',
    71 => 'Barra degli strumenti basici',
    72 => 'Barra degli strumenti comuni',
    73 => 'Barra degli strumenti avanzati',
    74 => 'Barra degli strumenti avanzati II',
    75 => 'In Vetrina',
    76 => 'Opzioni di Pubblicazione',
    77 => 'É necessario che Javascript sia attivato per utilizzare l\'"Editor Avanzato". É possibile disabilitare quest\'opzione nella configurazione principale di config.php',
    78 => 'Clicca <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">qui</a> per utilizzare il "default editor"',
    79 => 'Anteprima',
    80 => 'Editor',
    81 => 'Opzioni di pubblicazione',
    82 => 'Immagini',
    83 => 'Opzioni degli archivi',
    84 => 'Autorizzazioni',
    85 => 'Mostra Tutto',
    86 => 'Editor Avanzato',
    87 => 'Statistiche degli articoli',
    88 => 'Formato dello stile Wiki',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'É possibile estendere il tempo scadenza.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Editor Argomento',
    2 => 'ID Argomento',
    3 => 'Nome Argomento',
    4 => 'Immagine Argomento',
    5 => '(non utilizzare spazi)',
    6 => 'Eliminando un argomento eliminerai anche gli articoli e i blocchi ad esso associati',
    7 => 'Prego compila i campi ID Argomento e Nome Argomento',
    8 => 'Manager Argomenti',
    9 => 'Per modificare o eliminare un argomento, fai clic sull\'argomento selezionato. <br' . XHTML . '>Per creare un nuovo argomento fai clic su [ Nuovo ] in alto. <br' . XHTML . '>Dovresti trovare il tuoi permessi di accesso per ogni argomento elencati fra parentesi. L\'Asterisco (*) indica l\'argomento di default.',
    10 => 'Ordinamento',
    11 => 'Articoli/Pagina',
    12 => 'Accesso negato',
    13 => "Stai cercando di accedere a un argomento del quale non hai i permessi di visualizzazione.  Questo tentativo é stato registrato. Prego <a href=\"{$_CONF['site_admin_url']}/topic.php\">ritorna alla pagina amministrazione argomenti</a>.",
    14 => 'Metodo Ordinamento',
    15 => 'alfabetico',
    16 => 'per definizione é',
    17 => 'Nuovo Argomento',
    18 => 'Home Amministrazione',
    19 => 'Registra',
    20 => 'Annulla',
    21 => 'Elimina',
    22 => 'Default',
    23 => 'fai di questo l\'argomento di default per gli inserimenti dei nuovi articoli',
    24 => '(*)',
    25 => 'Argomento di Archivio',
    26 => 'rendi questo l\'argomento predefinito per gli articoli archiviati. Un solo argomento permesso.',
    27 => 'O carica un icona per l\'argomento',
    28 => 'Massimo',
    29 => 'Errori di caricamento dei file',
    30 => 'Articoli per l\'argomento'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Editor Utenti',
    2 => 'ID Utente',
    3 => 'Nome Utente',
    4 => 'Nome Completo',
    5 => 'Password',
    6 => 'Livello di Sicurezza',
    7 => 'Indirizzo E-mail',
    8 => 'Homepage',
    9 => '(non utilizzare spazi)',
    10 => 'Prego compila i campi Nome Utente e Indirizzo E-mail',
    11 => 'Manager Utenti',
    12 => 'Per modificare o eliminare un utente, fai clic su un utente quí sotto. <br' . XHTML . '>Per creare un nuovo utente fai clic sul bottone [ Nuovo Utente ] in alto. <br' . XHTML . '>Per eseguire una ricerca semplice inserisci parti di nome utente,indirizzo e-mail o nome completo (es.*son* or *.edu) nel form sottostante.',
    13 => 'Liv. Sic.',
    14 => 'Data Reg.',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'Registra',
    21 => 'Il Nome Utente che stai tentando di registrare é giá presente nel database.',
    22 => 'Errore',
    23 => 'Aggiungi (Batch)',
    24 => 'Importazione Batch di Utenti',
    25 => 'Puoi importare un batch di utenti in Geeklog. Il file da importare deve essere delimitato da tab di spaziatura e deve avere i campi nel seguente ordine: nome completo, nome utente, indirizzo e-mail.  a ogni utente che importi sará inviata una mail con una password casuale.  Devi avere un utente per ogni riga del file.  La non corretta esecuzione delle seguenti istruzioni potrebbe causare problemi risolvibili solo con del lavoro manuale sul database, quindi fai molta attenzione alle tue operazioni!',
    26 => '',
    27 => '',
    28 => 'Fai clic quí per eliminare questa immagine',
    29 => 'Percorso',
    30 => 'Importa',
    31 => 'Nuovo Utente',
    32 => 'Processo Eseguito. Importato %d e incontrati %d problemi',
    33 => 'invia',
    34 => 'Errore: Devi specificare un file da caricare.',
    35 => 'Ultimo Accesso',
    36 => '(mai)',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Vietati',
    43 => 'In attesa di Attivazione',
    44 => 'In attesa di Autorizzazione ',
    45 => 'Attivo',
    46 => 'Stato Utente',
    47 => 'Modifica',
    48 => 'Mostra gruppo Amministratori',
    49 => 'Gruppo Amministratori',
    50 => 'Seleziona per nascondere questo gruppo di Ammistratori.',
    51 => 'Giorni Online',
    52 => '<br' . XHTML . '>Nota: "Giorni Online" é il numero di giorni trascorsi tra la registrazione dell\'utente e l\'ultimo login.',
    53 => 'registrato',
    54 => 'Batch Delete',
    55 => 'Questo funziona solo se hai <code>$_CONF[\'lastlogin\'] = true;</code> nel tuo file "config.php"',
    56 => 'Seleziona il tipo di utente che vuoi rimuovere e premi "Aggiorna Lista". Quindi deselziona dalla lista quelli che non vuoi rimuovere e premi "Rimuovi". Nota che rimuoverai solo quelli che solo visibili, se la lista é piú di una pagina.',
    57 => 'Utenti Fantasma',
    58 => 'Utenti Recenti',
    59 => 'Utenti Vecchi',
    60 => 'Utenti registrati piú di ',
    61 => ' mesi fá, ma non non hanno mai acceduto.',
    62 => 'Utenti registrati piú di ',
    63 => ' mesi fá, che hanno acceduto il sito entro 24 ore, ma non sono mai tornati.',
    64 => 'Utenti normali, che semplicemente non hanno visitato il tuo sito da ',
    65 => ' mesi.',
    66 => 'Aggiorna Lista',
    67 => 'Mesi dalla registrazione',
    68 => 'Ore Online',
    69 => 'Mesi Offline',
    70 => 'non é stato possibile rimuovere',
    71 => 'rimosso con successo',
    72 => 'Nessun utente selezionato per la rimozione',
    73 => 'Sei sicuro che vuoi rimuovere TUTTI gli utenti selezionati?',
    74 => 'Utenti recenti',
    75 => 'Utenti registrati negli ultimi ',
    76 => ' mesi',
    77 => 'Invia e-mail con dettagli di accesso agli utenti selezionati',
    78 => 'Invia Promemoria',
    79 => 'Nessun utente selezionato per il promemoria',
    80 => 'Promemoria inviato con successo',
    81 => 'Promemoria per verificare l\'account per %s',
    82 => "Il suo account su {$_CONF['site_name']} non é stato accesso da %s e verrá disabilitato se non accesso entro 30 goirni.",
    83 => "Il suo account su {$_CONF['site_name']} non é stato accesso da quando é stato creato e verrá rimosso se non saraáaccesso presto.",
    84 => "Il suo nome utente é: %s  per il nostro sito: {$_CONF['site_url']}",
    85 => 'Sei hai dimenticato la password, usa il seguente collegamento: %s',
    86 => 'Includi',
    87 => 'Promemoria',
    88 => 'Gruppo Predefinito',
    89 => 'Seleziona per rendere questo il gruppo predefinito per i nuovi utenti',
    90 => 'Applica il cambiamento al "Gruppo Predefinito" agli account degli utenti esistenti'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Approva',
    2 => 'Elimina',
    3 => 'Modifica',
    4 => 'Profilo',
    10 => 'Titolo',
    11 => 'Data inizio',
    12 => 'URL',
    13 => 'Categoria',
    14 => 'Data',
    15 => 'Argomento',
    16 => 'Nome Utente',
    17 => 'Nome Completo',
    18 => 'E-mail',
    34 => 'Console di Amministrazione',
    35 => 'Inserimento Articolo',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Invia',
    39 => 'Non ci sono inserimenti da moderare al momento',
    40 => 'Inserimenti Utente',
    41 => 'Commenti Inviati',
    42 => 'Nome utente',
    43 => 'Auto-Pubblicare Commenti?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} Mail Utility",
    2 => 'Da',
    3 => 'Rispondi a',
    4 => 'Soggetto',
    5 => 'Commento',
    6 => 'Invia a:',
    7 => 'Tutti gli utenti',
    8 => 'Amministrazione',
    9 => 'Opzioni',
    10 => 'HTML',
    11 => 'Messaggio urgente!',
    12 => 'Invia',
    13 => 'Azzera',
    14 => 'Ignora preferenze utente',
    15 => 'Errore nell\'invio a: ',
    16 => 'Messaggio inviato correttamente a: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Invia un'altro messaggio</a>",
    18 => 'A',
    19 => 'NOTA: se vuoi inviare un messaggio a tutti i membri del sito, seleziona il gruppo Logged-in Users dalla lista.',
    20 => "Messaggi inviati correttamente <successcount> e messaggi non inviati <failcount>. Se lo necessiti, i dettagli di ogni messaggio sono elencati sotto.  Altrimenti puoi <a href=\"{$_CONF['site_admin_url']}/mail.php\">Inviare un'altro messaggio</a> o puoi <a href=\"{$_CONF['site_admin_url']}/moderation.php\">ritornare alla pagina amministrazione</a>.",
    21 => 'Fallito',
    22 => 'Eseguito correttamente',
    23 => 'Nessun errore',
    24 => 'Nessuna esecuzione',
    25 => '-- Seleziona Gruppo --',
    26 => 'Prego compila tutti i campi del form e seleziona un gruppo dal menú a tendina.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'L\'Installazione di plug-in potrebbe provocare danni alla tua installazione di Geeklog ed eventualmente anche il tuo sistema. É importante che tu installi solo i plug-in scaricati dalla <a href="http://www.geeklog.net" target="_blank">Homepage di Geeklog</a> in quanto questi plug-in vengono regolarmente testati da noi su numerosi sistemi operativi. E\' altresí importante che tu capisca che il processo di installazione richiede l\'esecuzione di alcuni comandi di sistema che potrebbero intaccare la sicurezza del sistema stesso (in particolare se utilizzi plug-in di terze parti). Anche con questo avvertenza che ti diamo, noi non garantiamo il successo della installazione e non siamo responsabili di eventuali danni causati dall\'installazione di plug-in. In altre parole, installa a tuo rischio!. Per gli amanti del rischio,  indicazioni su come installare manualmente un plug-in sono incluse in ogni pacchetto plug-in.',
    2 => 'Note di Installazione Plug-in',
    3 => 'Form Installazione Plug-in',
    4 => 'Plug-in File',
    5 => 'Lista Plug-in',
    6 => 'Attenzione: Plug-in giá installato!',
    7 => 'Il plug-in che vuoi installare é gia installato nel sistema. Elimina il plug-in esistente prima di reinstallare la nuova versione',
    8 => 'Controllo Compatibilitá Plug-in Fallita',
    9 => 'Questo plug-in richiede una nuova versione di Geeklog. Puoi aggiornare la tua copia di <a href=http://www.geeklog.net>Geeklog</a> o prendere una nuova versione del plug-in.',
    10 => '<br' . XHTML . '><b>Al momento nessun plug-in risulta installato.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'Per modificare o eliminare un plug-in, fai clic sul numero del plug-in dalla lista sottostante. <br' . XHTML . '>Per apprendere su come usare il plug-in, fai clic sul nome del plug-in e sarai redirezionato direttamente al sito del plug-in. <br' . XHTML . '>Per installare o aggiornare un plug-in fai clic su nuovo-plug-in sopra.',
    12 => 'nessun nome di plug-in fornito da plugineditor()',
    13 => 'Editor Plug-in',
    14 => 'Nuovo Plug-in',
    15 => 'Home Amministrazione',
    16 => 'Nome Plug-in',
    17 => 'Versione Plug-in',
    18 => 'Versione Geeklog',
    19 => 'Abilitato',
    20 => 'Si',
    21 => 'No',
    22 => 'Installa',
    23 => 'Registra',
    24 => 'Annulla',
    25 => 'Elimina',
    26 => 'Nome Plug-in',
    27 => 'Homepage Plug-in',
    28 => 'Versione Plug-in',
    29 => 'Versione Geeklog',
    30 => 'Elimina Plug-in?',
    31 => 'Sei sicuro di voler eliminare questo plug-in? Cosí facendo eliminerai anche tutti i file associati, dati e struttura utilizzati da questo plug-in. Se sei sicuro, fai clic su elimina nel form sottostante.',
    32 => '<p><b>Errore, formato tag AutoLink errato</b></p>',
    33 => 'Versione Codice',
    34 => 'Aggiorna',
    35 => 'Modifica',
    36 => 'Code',
    37 => 'Data',
    38 => 'Aggiorna!',
    39 => 'Carica una plug-in',
    40 => 'Puoi caricare una plug-in compressa (.tar.gz, .tgz, .zip) direttamente qui:',
    41 => 'Carica',
    42 => 'Clicca per aggiornare',
    99 => 'Si é verificato un errore sconosiuto',
    100 => 'Ok.',
    101 => 'Il file caricato eccede la direttiva upload_max_filesize in php.ini.',
    102 => 'Il file caricato eccede la direttiva MAX_FILE_SIZE specificatat nel form HTML.',
    103 => 'Il file é stato caricato solo parzialmente.',
    104 => 'Nessun file é stato caricato.',
    105 => '(errore sconosiuto)',
    106 => 'Non é stat trovata una cartella temporaria.',
    107 => 'Impossibile scrivere il file sul disco.',
    108 => 'Caricamento del file é stato fermato da un estenzione.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'crea feed',
    2 => 'registra',
    3 => 'elimina',
    4 => 'annulla',
    10 => 'Content Syndication',
    11 => 'Nuovo Feed',
    12 => 'Home Admin',
    13 => 'Per modificare o eliminare un feed, fai clic sul titolo del feed sotto. Per creare un nuovo feed, fai clic su Nuovo Feed sopra.',
    14 => 'Titolo',
    15 => 'Tipo',
    16 => 'Nome File',
    17 => 'Formato',
    18 => 'ultimo aggiornamento',
    19 => 'Abilitato',
    20 => 'Si',
    21 => 'No',
    22 => '<i>(nessun feed)</i>',
    23 => 'tutte gli Articoli',
    24 => 'Editor di Flussi',
    25 => 'Titolo del Flusso',
    26 => 'Limita',
    27 => 'Lunghezza elementi',
    28 => '(0 = senza testo, 1 = testo completo, altro = limita a questo numero di caratteri.)',
    29 => 'Descriztione',
    30 => 'Ultimo Aggiornamento',
    31 => 'Set Caratteri',
    32 => 'Lingua',
    33 => 'Contenuti',
    34 => 'Elementi',
    35 => 'Ore',
    36 => 'Seleziona il tipo del feed',
    37 => '',
    38 => 'Errore: Campi Mancanti',
    39 => 'Prego inserire Titolo Feed, Descrizione e Nome File.',
    40 => 'Prego inserire un numero di elementi o un numero di ore.',
    41 => 'Collegamento',
    42 => '',
    43 => 'Tutto',
    44 => 'Nessuno',
    45 => 'Header-link nell\'argomento',
    46 => 'Limita i risultati',
    47 => 'Cerca',
    48 => 'Modifica',
    49 => 'Logo del Flusso',
    50 => "Relativo all'indirizzo del sito ({$_CONF['site_url']})",
    51 => 'Il nome del file selezionato é giá utilizzato da un altra \'feed\'. Scegli un altro nome.',
    52 => 'Errore: il nome del file é giá utilizzato',
    53 => 'Tutti gli articoli di copertina',
    54 => 'Seleziona il tipo di flusso da creare.',
    55 => 'Articoli'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "La password é stata inviata all'indirizzo e-mail da te fornito, dovrebbe arrivare a momenti. Prego segui le istruzioni del messaggio per accedere al sito e grazie per il tuo supporto a {$_CONF['site_name']}",
    2 => "Grazie per aver inserito un articolo in {$_CONF['site_name']}.  L'evento é stato inviato al nostro staff per l'approvazione. Se approvato, il tuo articolo sará disponibile per la visualizzazione nel nostro sito.",
    3 => '',
    4 => '',
    5 => 'Le tue informazioni utente sono state registrate correttamente.',
    6 => 'Le tue preferenze di visualizzazione sono state registrate correttamente.',
    7 => 'Le tue preferenze commenti sono state registrate correttamente.',
    8 => 'Sei uscito dall\'area utenti correttamente.',
    9 => 'Il tuo articolo é stato registrato correttamente.',
    10 => 'L\'articolo é stato eliminato correttamente.',
    11 => 'Il tuo blocco é stato registrato correttamente.',
    12 => 'Il blocco é stato eliminato correttamente.',
    13 => 'Il tuo argomento é stato registrato correttamente.',
    14 => 'L\'argomento e tutte gli articoli e blocchi associati sono stati eliminati correttamente.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Il nuovo utente é stato registrato correttamente.',
    22 => 'L\'utente é stato eliminato correttamente',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Il Messaggio é stato inviato correttamente.',
    28 => 'Il plug-in é stato registrato correttamente',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Accesso negato',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Messaggio di Sistema',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Il plug-in é stato installato correttamente!',
    45 => 'Il plug-in é stato eliminato correttamente.',
    46 => '',
    47 => '',
    48 => "Grazie per la tua richiesta di registrazione a {$_CONF['site_name']}. Il nostro Team valuterá la tua richiesta. Se approvata ti verrá inviata via posta elettronica la password alla casella e-mail da te specificata.",
    49 => 'Il tuo gruppo é stato registrato correttamente.',
    50 => 'Il gruppo é stato eliminato correttamente.',
    51 => 'Questo Nome Utente é giá in uso. Prego selezionane un\'altro.',
    52 => 'L\'indirizzo e-mail da té inserito non sembra essere un indirizzo e-mail valido.',
    53 => 'La tua nuova password é stata accettata. Prego usa la tua nuova password per riaccedere al sito.',
    54 => 'La tua richiesta per una nuova password é spirata. Prego riprova di nuovo.',
    55 => 'Una e-mail ti é stata inviata e dovrebbe arrivare a breve. Prego segui le istruzioni contentute nel messaggio per impostare una nuova password per il tup account.',
    56 => 'L\'indirizzo e-mail da te fornito é giá in uso per un altro account.',
    57 => 'Il tuo account é stato eliminato.',
    58 => 'Il tuo feed &egrave stato registrato correttamente.',
    59 => 'Il feed &egrave stato eliminato correttamente.',
    60 => 'Il plug-in &egrave stato aggiornato correttamente',
    61 => 'Plug-in %s: Segnaposto messaggio sconosciuto',
    62 => 'Tutti i commenti di trackback sono stati disabilitati.',
    63 => 'Si é verificato un errore durante l\'eliminazione di un commento di trackback.',
    64 => 'I tuo commento di trackback é stato inviato con successo.',
    65 => 'Servizio Weblog salvato con successo.',
    66 => 'Servizio Weblog rimosso con successo.',
    67 => 'La nuova password non corrisponde alla password di conferma!',
    68 => 'Devi inserire la tua corrente password.',
    69 => 'Il tuo account é stato bloccato!',
    70 => 'Il tuo account é in attesa di approvazione da un amministratore.',
    71 => 'Il tuo account é ora confermato ed é in attesa di conferma da un amministratore.',
    72 => 'Si é verificato un errore durante l\'installazione del plug-in. Puoi vedere error.log per dettagli.',
    73 => 'Si é verificato un errore durante la disinstallazione del plug-in. Puoi vedere error.log per dettagli.',
    74 => 'Il pingback é stato inviato correttamente.',
    75 => 'I Trackback devono essere inviati tramite un riqiesta del tipo POST.',
    76 => 'Sei sicuro di voler eliminare questo oggetto?',
    77 => 'ATTENZIONE:<br' . XHTML . '>Hai selezionato UTF-8 come la tua codifica predefinita. Peró il tuo server non supporta codifiche del tipo "multibyte". Installa le funzioni "mbstring" per PHP o selezionare una codifica/lingua differente.',
    78 => 'Assicurati che l\'indirizzo e-mail corrisponde all\'indirizzo email di conferma.',
    79 => 'La pagina alla quale hai cercato di accedere si riferisce ad una funzione che non esiste su questo sito.',
    80 => 'La plugin che ha creato questo flusso é al momento disabilitata. Non sará possibile modificare questo flusso finche la plugin non sará attivata.',
    81 => 'É possibile che hai scritto i tuoi dettagli di accesso incorrettemente.',
    82 => 'Hai suprato il numero massimo di tentativi di accesso. Prova piú tardi.',
    83 => 'Per cambiare la tua password, indirizzo e-mail, o per quanto tempo rimemberti, prego inserisci la tua password.',
    84 => 'Per rimuovere il tuo account, prego inserisci la tua password.',
    85 => 'Si é verificato un errore durante l\'invio dell\'e-mail.',
    86 => 'Il server OpenID ha rifiutato la tua richiesta di accesso.',
    87 => 'L\'operazione di accesso tramite OpenID é stata annullata dall\'utente.',
    88 => 'Il server OpenID ha risposto con un errore.',
    89 => 'Non é possibile trovare un server OpenID per l\'indirizzo fornito.',
    90 => 'Identificazione OpenID annullata.',
    91 => 'Indirizzo non valido.',
    92 => "<a href=\"{$_CONF['site_admin_url']}/sectest.php\">Verifica la sicurezza del tuo sito</a> prima di utilizzarlo!",
    93 => 'Il backup del database é stato completato con successo.',
    94 => 'Backup Fallito: Dimensione del file é inferiore a 1kb',
    95 => 'Si é verificato un errore.',
    96 => '',
    97 => '',
    98 => 'La plug-in é stata caricata con successo.',
    99 => 'La plug-in giá esiste.',
    100 => 'Il file della plug-in caricata non era un archivio compresso del tipo Zip o GZip.',
    101 => 'Nessun argomento disponibile (ai quali hai accesso). Hai bisogno di almeno un argomento per inviare gli articoli.',
    400 => 'Non tutti i campi sono stati validati con successo.',
    401 => 'Inserisci il tuo nome completo'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Accessi',
    'ownerroot' => 'Proprietario/Root',
    'group' => 'Gruppo',
    'readonly' => 'Sola-Lettura',
    'accessrights' => 'Permessi di Accesso',
    'owner' => 'Proprietario',
    'grantgrouplabel' => 'Grant Above Group Edit Rights',
    'permmsg' => 'NOTA: i membri sono tutti gli utenti registrati nel sito e anonimi tutti i rimanenti visitatori non registrati.',
    'securitygroups' => 'Sicurezza Gruppi',
    'editrootmsg' => "Ricorda! Anche se sei un Utente Amministratore, non puoi modificare l'utente root senza essere prima entrato con l'account di root. Puoi modificare tutti gli gli altri utenti ad eccezzione dell'utente root. Prego nota che tutti i tentativi di modificare illegalmente l'utente root vengono registrati. Ritorna a <a href=\"{$_CONF['site_admin_url']}/user.php\">Pagina Ammin. Utenti</a>.",
    'securitygroupsmsg' => 'Seleziona la casella per i gruppi nei quali vuoi inserire l\'utente.',
    'groupeditor' => 'Editor Gruppi',
    'description' => 'Descrizione',
    'name' => 'Nome',
    'rights' => 'Permessi',
    'missingfields' => 'Campi Mancanti',
    'missingfieldsmsg' => 'Devi fornire un nome e una descrizione per il gruppo',
    'groupmanager' => 'Manager Gruppi',
    'newgroupmsg' => 'Per modificare o eliminare un gruppo, selezionalo dalla lista sottostante. <br' . XHTML . '>Per creare un nuovo gruppo fai clic su [ Nuovo Gruppo ] sopra. <br' . XHTML . '>Considera che il gruppo principale non puó essere eliminato in quanto usato dal sistema.',
    'groupname' => 'Nome Gruppo',
    'coregroup' => 'Gruppo Principale',
    'yes' => 'Si',
    'no' => 'No',
    'corerightsdescr' => "Questo Gruppo di {$_CONF['site_name']} é il gruppo principale. Per definizione i permessi di questo gruppo non possono essere modificati.  Sotto c'é la lista in sola lettura dei permessi a cui questo gruppo ha accesso.",
    'groupmsg' => 'Il modello di sicurezza per i Gruppi in questo sito é di tipo gerarchico.  Aggiungendo questo gruppo a uno qualsiasi dei gruppi elencati sotto fa sí che il gruppo prenda gli stessi permessi del gruppo superiore.  Dove possibile siete incoraggiati a usare i gruppi sottostanti per dare i permessi al gruppo.  Se avete necessitá di dare dei permessi personalizzati al gruppo potete selezionare i permessi fra le varie funzioni del sito nella sezione chiamata \'Permessi\'.  Per aggiungere questo gruppo a uno dei gruppi sottostanti seleziona la spunta nella caselle del gruppo(i) che desideri modificare.',
    'coregroupmsg' => "Questo gruppo é il gruppo principale di {$_CONF['site_name']} .  Normalmente i gruppi che sono sottostanti a questo gruppo non posono essere modificati.  Sotto puoi trovare una lista in sola lettura dei gruppi associati a questo gruppo.",
    'rightsdescr' => 'Alcuni permessi di accesso ai gruppi possono essere settati direttamente al gruppo o a un gruppo differente facente parte del gruppo.  Quelli che vedi sotto non selezionati sono i permessi che sono stati impostati a questo gruppo in quanto facente parte di altri gruppi e quindi ereditati.  I permessi selezionabili sono i permessi che posono essere dati direttamente a questo gruppo.',
    'lock' => 'Bloccato',
    'members' => 'Membro',
    'anonymous' => 'Anonimo',
    'permissions' => 'Permessi',
    'permissionskey' => 'R = lettura, E = modifica, permesso di modifica implica permessi di lettura',
    'edit' => 'Modifica',
    'none' => 'Nessuno',
    'accessdenied' => 'Accesso negato',
    'storydenialmsg' => "Non disponi dei permessi per visualizzare questo articolo. Questo perché non sei un membro registrato di {$_CONF['site_name']}.  Prego <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> diventa un membro</a> of {$_CONF['site_name']} per avere pieno accesso al sito!",
    'nogroupsforcoregroup' => 'Questo Gruppo non ha alcun collegamento con gli altri gruppi',
    'grouphasnorights' => 'Questo Gruppo non ha accesso a nessuna funzione amministrativa del sito',
    'newgroup' => 'Nuovo Gruppo',
    'adminhome' => 'Home Amministratore',
    'save' => 'Salva',
    'cancel' => 'Annulla',
    'delete' => 'Elimina',
    'canteditroot' => 'Hai provato a modificare il Gruppo Root ma non fai parte del gruppo stesso e quindi la tua modifica non é consentita. Prego contatta gli Amministratori se ritieni questo messaggio un errore',
    'listusers' => 'Lista Utenti',
    'listthem' => 'lista',
    'usersingroup' => 'Utenti nel gruppo %s',
    'usergroupadmin' => 'Amministrazione Gruppi Utenti',
    'add' => 'Aggiungi',
    'remove' => 'Rimouvi',
    'availmembers' => 'Membri Disponibili',
    'groupmembers' => 'Membri del Gruppo',
    'canteditgroup' => 'Per modificare questo gruppo, devi esserne membro. Prego contatta l\'amministratore del sistema se pensi si tratti di un errore.',
    'cantlistgroup' => 'Per vedere i membri di questo gruppo, deve esserne membro tu stesso. Prego contatta l\'amministratore del sistema se pensi si tratti di un errore.',
    'editgroupmsg' => 'Per modificare i membri del gruppo clicca su nome/nomi ed utilizza i pulsanti "aggiungi" o "rimuovi". Se l\'utente é fá parte di un gruppo, il suo nome verrá visualizato solo sul lato destro. Quando hai aompletatto - premi il pulsante "<b>Salva</b>" per aggiornare il gruppo e ritornare alla pagina amministrativa dei gruppi principale.',
    'listgroupmsg' => 'Elenco di tutti i membri del gruppo corrente: <b>%s</b>',
    'search' => 'Cerca',
    'submit' => 'Invia',
    'limitresults' => 'Limita Risultati',
    'group_id' => 'ID del Gruppo',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Il nome del Gruppo é giá utilizzato',
    'groupexistsmsg' => 'Il nome del Gruppo é giá utilizzato. Nomi dei gruppi devomo essere unici.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Ultimi 10 Backup',
    'do_backup' => 'Esegui il Backup',
    'backup_successful' => 'Il Backup é stato eseguito correttamente.',
    'db_explanation' => 'Per creare un nuovo Backup del tuo sistema Geeklog, fai clic sul bottone sottostante',
    'not_found' => "Percorso non corretto o utility mysqldump non eseguibile.<br" . XHTML . ">Controlla il percorso <strong>\$_DB_mysqldump_path</strong> in config.php.<br" . XHTML . ">La variabile attualmente é definitá come: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Backup Fallito: La dimensione del File era di 0 bytes',
    'path_not_found' => "{$_CONF['backup_path']} non esiste o non é una directory",
    'no_access' => "ERRORE: La cartella {$_CONF['backup_path']} non é accessibile.",
    'backup_file' => 'File di backup',
    'size' => 'Dim.',
    'bytes' => 'Byte',
    'total_number' => 'Numero Totale di backup: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'Nuovo Backup',
    'delete_failure' => 'Non é stato possibile eliminare uno o piú file.',
    'delete_success' => 'File di backup eliminati con successo.',
    'convert_menu' => 'Converti a InnoDB',
    'convert_title' => 'Converti a tabelle InnoDB',
    'convert_button' => 'Converti',
    'sorry_no_innodb' => 'Scusa, ma la tua versione di MySQL non supporta tabelle InnoDB.',
    'innodb_explain' => 'Tabelle del tipo InnoDB offrono migliori prestazioni per databasi <em>molto</em> grandi, ma complicano il processo del backup.  <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">Leggi</a> a proposito degli pro ed i contro di queste tabelle prima di proseguire.',
    'already_converted' => 'Nota: Sembra che tutte le tabelle sono giá del tipo InnoDB.',
    'conversion_patience' => 'Nota: La conversione potrebbe richiedere del tempo - si prega di attendere.',
    'innodb_success' => 'Le tabelle sono state convertite a InnoDB con successo.',
    'table_issues' => 'Ci potrebbero essere stati degli errori. Vedi error.log per dettagli.',
    'optimize_menu' => 'Ottimizza Tabelle',
    'optimize_title' => 'Ottimizza Tabelle',
    'optimize_button' => 'Ottimizza',
    'optimize_explain' => 'Ottimizare le tabbele potrebbe migliorare le prestazioni del tuo sito. Effettivamente dipende dall\'utilizzo delle tabbelle, certe tabbelle potrebbero usufrirne piú di altre. Non aspettarti un grande miglioramento. Il <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">manuale di MySQL</a> dice: <q>non è probabile che avrai bisogno di eseguire l\'ottimizzazione piú di a volta a settimana o al mese</q>.',
    'last_optimization' => 'Ultima ottimizzazione',
    'optimization_patience' => 'Nota: L\'ottimizzazione potrebbe richiedere del tempo - si prega di attendere.',
    'optimize_success' => 'Ottimizzazione completata con successo.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Home',
    2 => 'Contatti',
    3 => 'Pubblica',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Statistiche Sito',
    8 => 'Preferenze',
    9 => 'Ricerca',
    10 => 'Ricerca Avanzata',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => 'Errore 404',
    2 => 'Attenzione, Abbiamo cercato in tutto il sito ma l\'argomento <b>%s</b> non é stato trovato.',
    3 => 'Siamo spiacenti, ma il file da te richiesto non esiste. Prego controlla nella pagina principale o nella pagina di ricerca per vedere se puoi trovare quanto da te richiesto.'
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Autenticazione richiesta',
    2 => 'Spiacenti, per accedere a questa area devi essere registrato come utente.',
    3 => 'Entra',
    4 => 'Nuovo Utente'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'da',
    'tracked_on' => 'Trackback effettuato',
    'read_more' => '[ leggi ]',
    'intro_text' => 'Qui puoi vedere cosa gli altri dicono di \'%s\':',
    'no_comments' => 'Nessun commento di trackback.',
    'this_trackback_url' => 'L\'indirizzo di Trackback per quest\'inserimento:',
    'num_comments' => '%d commenti di trackback',
    'send_trackback' => 'Invia Ping',
    'preview' => 'Anteprima',
    'editor_title' => 'Invia commento di trackback',
    'trackback_url' => 'Indirizzo di Trackback',
    'entry_url' => 'Indirizzo dell\'inserimento',
    'entry_title' => 'Titolo dell\'inserimento',
    'blog_name' => 'Nome del Sito',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Nota: Il sito ricettore potrebbe bloccare excerpt',
    'button_send' => 'Invia',
    'button_preview' => 'Anteprima',
    'send_error' => 'Errore',
    'send_error_details' => 'Errore con l\'invio del commento di trackback:',
    'url_missing' => 'Nessun indirizzo per l\'inserimento',
    'url_required' => 'Inserischi almeno l\'indirizzo per l\'inserimento.',
    'target_missing' => 'Nessun indirizzo di Trackback',
    'target_required' => 'Inserischi un indirizzo di trackback',
    'error_socket' => 'Impossibile aprire il socket.',
    'error_response' => 'Risposta Incomprensibile.',
    'error_unspecified' => 'Errore sconosciuto.',
    'select_url' => 'Scegli l\'indirizzo di Trackback',
    'not_found' => 'Indirizzo di Trackback non trovato',
    'autodetect_failed' => 'Geeklog non é stato in grado di trovare l\'indirizzo di Trackback per l\'articolo scelto. Prego scrivilo manualmente qui sotto.',
    'trackback_explain' => 'Scegli dove vuoi inviare il commento di trackback da gli indirizzi sottostanti. Geeklog cercher&arave; di determinare l\'indirizzo corretto. Or puoi <a href="%s">inserirlo manualmente</a> se lo conosci gia.',
    'no_links_trackback' => 'Non é statto trovato nessun collegamento. Quindi non é possibile inviare un commento di trackback.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Risultati di Pingback',
    'send_pings' => 'Invia Ping',
    'send_pings_for' => 'Invia Ping a "%s"',
    'no_links_pingback' => 'Non é statto trovato nessun collegamento. Quindi nessun pingback é stato inviato.',
    'pingback_success' => 'Pingback inviato.',
    'no_pingback_url' => 'Non é statto trovato nessun indirizzo di pingback.',
    'resend' => 'Invia un altra volta',
    'ping_all_explain' => 'Puoi noticare i sito ai quali hai creato collegamenti (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), inviando un ping ai servizi weblog pubblicizzare che il tuo sito &estato; aggiornato, or inviare un commento di <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> se hai scritto un articolo sul sito di qualcun\' altro.',
    'pingback_button' => 'Invia Pingback',
    'pingback_short' => 'Invia Pingback da qui a tutti i siti.',
    'pingback_disabled' => '(Pingback disabilitato)',
    'ping_button' => 'Invia Ping',
    'ping_short' => 'Invia Ping ai servizi weblog.',
    'ping_disabled' => '(Ping disabilitato)',
    'trackback_button' => 'Invia Trackback',
    'trackback_short' => 'Invia un commento di Trackback.',
    'trackback_disabled' => '(Trackback disabilitato)',
    'may_take_a_while' => 'Nota che l\'invio di Pingback e Ping potrebbe richiedere del tempo.',
    'ping_results' => 'Risultati di Ping',
    'unknown_method' => 'Metodo di ping sconosciuto',
    'ping_success' => 'Ping inviato.',
    'error_site_name' => 'Inserisci il nome del sito.',
    'error_site_url' => 'Inserisci l\'indirizzo del sito.',
    'error_ping_url' => 'Inserisci l\'indirizzo di ping.',
    'no_services' => 'Nessun servizio di weblog impostato.',
    'services_headline' => 'Servizi di Weblog',
    'service_explain' => 'Clicca sull\'icona di modifica di un servizio di weblog per modificarlo o eliminarlo. Clicca su "Nuovo" per aggiungere un nuovo servizio di weblog.',
    'service' => 'Servizio',
    'ping_method' => 'Metodo di Ping',
    'service_website' => 'Sito Internet',
    'service_ping_url' => 'Indirizzo di ping',
    'ping_standard' => 'Ping Normale',
    'ping_extended' => 'Ping Prolungato',
    'ping_unknown' => '(metodo sconosciuto)',
    'edit_service' => 'Modifica Servizio di Weblog',
    'trackbacks' => 'Trackback',
    'editor_intro' => 'Prepara il tuo commento di trackback per <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepara il tuo commento di trackback.',
    'trackback_note' => 'Per inviare un commento di trackback per un articolo vai alla lista delle storie e clicca su "Invia Ping". <a href="%s">Clicca qui</a> per inviare un trackback ad una storia estranea.',
    'pingback_explain' => 'Inserisci l\'indirizzo per l\'invio di pingback. Il pingback non collecherá alla homepage del tuo sito.',
    'pingback_url' => 'Indirizzo di Pingback',
    'site_url' => 'Indirizzo di questo sito',
    'pingback_note' => 'Per inviare un pingback per un articolo vai alla lista delle storie e clicca su "Invia Ping". <a href="%s">Clicca qui</a> per inviare unpingback ad una storia estranea.',
    'pbtarget_missing' => 'Nessun indirizzo di pingback',
    'pbtarget_required' => 'Inserisci un indirizzo di pingback',
    'pb_error_details' => 'Si é verificato un errore durante l\'invio del pingback:',
    'delete_trackback' => 'Clicca per eliminare questo trackback: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Directory di Articoli',
    'title_year' => 'Directory di Articoli per %d',
    'title_month_year' => 'Directory di Articoli per %s %d',
    'nav_top' => 'Ritorna alla Directory di Articoli',
    'no_articles' => 'Nessun articolo.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Controllo di sicurezza di Geeklog',
    'results' => 'Risultati del controllo di sicurezza',
    'okay' => 'Tutto sembra di essere in ordine.',
    'please_fix' => 'É di corregere i problemi sovrastanti prima di utilizzare il sito!',
    'please_note' => 'Nota che nessun sito é mai sicuro all 100%. Questo programma controlla solo ploblemi ovvi.',
    'stay_informed' => 'Per essere informato di nuove versioni pubblicate di Geeklog e di possibili problemi di sicurezza, é suggerito che ti sottoscrivi alla mailing list %s (basso volume) o che ogni tanto usi l\'opzione %s nel menu amministrativo per controllare per la disponibilitá di aggiornamenti.',
    'public_html' => '"public_html" non deve mai fare parte dell\'indirizzo del tuo sito. Leggi la parte riguardante public_html nel %s ulterioramente e di modificare l\'installazione prima di procedere.',
    'installation' => 'istruzioni per l\'installazione',
    'directory' => 'cartella',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'Questo é un pericolo per la sicurezza e deve essere aggiustato!',
    'reachable' => '%s é accessibile dal Web.',
    'not_reachable' => 'Ottimo! %s non é accessibile dal Web.',
    'not_sure' => 'Il risultato %s é stato ricevuto mentre %s veniva esaminato. Scusa, ma non so cosa significa ...',
    'remove_inst' => 'C\'é bisogno che rimuovi la cartella di installazione %s nonappena il tuo sito funziona senza errori.',
    'remove_inst2' => 'Se viene lascita, utenti con cattive intenzioni potranno avere la possibilitá di rovinare la tua installazione, prendere il controllo del sito o accedere ad importanti informazioni.',
    'inst_removed' => 'Ottimo! Hai giá rimosso la cartella di installazione.',
    'fix_password' => 'Non hai ancora cambiato la <strong>password predefinita</strong> "password" su %s account del tipo Root.',
    'password_okay' => 'Ottimo! Sembra che hai giá cambiato la password predefinita.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n nuovi %i negli ultimi %t %s',
    'new_last' => 'ultimi %t %s',
    'minutes' => 'minuti',
    'hours' => 'ore',
    'days' => 'giorni',
    'weeks' => 'settimane',
    'months' => 'mesi',
    'years' => 'years',
    'minute' => 'minuti',
    'hour' => 'ora',
    'day' => 'giorno',
    'week' => 'settimana',
    'month' => 'mese',
    'year' => 'year'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Gennaio',
    2 => 'Febbraio',
    3 => 'Marzo',
    4 => 'Aprile',
    5 => 'Maggio',
    6 => 'Giugno',
    7 => 'Luglio',
    8 => 'Agosto',
    9 => 'Settembre',
    10 => 'Ottobre',
    11 => 'Novembre',
    12 => 'Dicembre'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Domenica',
    2 => 'Lunedí',
    3 => 'Martedí',
    4 => 'Mercoledí',
    5 => 'Giovedí',
    6 => 'Venerdí',
    7 => 'Sabato'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Ricerca',
    'limit_results' => 'Limita risultati',
    'submit' => 'Invia',
    'edit' => 'Modifica',
    'edit_adv' => 'Modifica Azanzata',
    'admin_home' => 'Ammin Home',
    'create_new' => 'Nuovo',
    'create_new_adv' => 'Nuovo (Avanzato)',
    'enabled' => 'Abilitato',
    'title' => 'Titolo',
    'page_title' => 'Titolo della Pagina',
    'type' => 'Tipo',
    'topic' => 'Argomento',
    'help_url' => 'Indirizzo per il File della Guida',
    'save' => 'Salva',
    'cancel' => 'Annulla',
    'delete' => 'Elimina',
    'delete_sel' => 'Elimina la selezione',
    'copy' => 'Copia',
    'no_results' => '- Non é stato trovato alcun risultato -',
    'data_error' => 'Si é verificato un errore con la sottoscrizione. Controlla l\'origine dei dati.',
    'preview' => 'Anteprima',
    'records_found' => 'Risultati Trovati',
    'addchild' => 'Aggiungi',
    'list' => 'lista',
    'list_all' => 'Mostra tutti',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'Puoi modificare fino a %s. Dopo di che il codice di sicurezza impresso in questa pagina scadrá e tutte le modifiche verrano perse.',
    'token_expired' => 'Il codice di sicurezza per questa azione é scaduto. Si prega di autenticarsi di nuovo per procedere.',
    'reauth_msg' => 'Il codice di sicurezza per questa azione é scaduto. Se vuoi proseguire con quest\'azione, ti devi autenticare di nuovo. Questo permetterá di salvare le tue recenti modifiche.',
    'authenticate' => 'Autenticati'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Commenti Abilitati',
    -1 => 'Commenti Disabilitati',
    1 => 'Commenti Chiusi'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(nulla)',
    3600 => '1 Ora',
    7200 => '2 Ore',
    10800 => '3 Ore',
    28800 => '8 Ore',
    86400 => '1 Giorno',
    604800 => '1 Settimana',
    2678400 => '1 Mese'
);

$LANG_dateformats = array(
    0 => 'Predefinito del Sistema'
);

$LANG_featurecodes = array(
    0 => 'Non "In Vetrina"',
    1 => '"In Vetrina"'
);

$LANG_frontpagecodes = array(
    0 => 'Mostra solo nell\'articolo',
    1 => 'Mostra in Copertina'
);

$LANG_postmodes = array(
    'plaintext' => 'Testo non formattato',
    'html' => 'Testo in formato HTML'
);

$LANG_sortcodes = array(
    'ASC' => 'Piú vecchi prima',
    'DESC' => 'Piú nuovi prima'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Abilitato',
    -1 => 'Trackback Disabilitato'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Amministrazione del Sito',
    'sections' => 'Sezioni di Configurazione',
    'restore' => 'Recupera',
    'add_element' => 'Aggiungi Elemento',
    'save_changes' => 'Salva elemento',
    'reset_form' => 'Resetta il Form',
    'changes_made' => 'I cambiamenti sono stati applicati con successo a',
    'title' => 'Gestione della Configurazione',
    'disable' => 'Clicca per disabilitare quest\'opzione',
    'enable' => 'Abilita'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Configurazione di Geeklog'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'Percorso HTML',
    'site_url' => 'Indirizzo del sito',
    'site_admin_url' => 'Admin URL',
    'site_mail' => 'E-Mail del sito',
    'noreply_mail' => 'E-Mail di No-Reply',
    'site_name' => 'Nome del sito',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Microsummary',
    'path_log' => 'Percorso per Log',
    'path_language' => 'Lingua',
    'backup_path' => 'Backup',
    'path_data' => 'Data',
    'path_images' => 'Immagini',
    'path_pear' => 'Percorso per PEAR',
    'have_pear' => 'Hai installato PEAR?',
    'mail_settings' => 'Impostazioni Posta ',
    'allow_mysqldump' => 'Allow MySQL Dump',
    'mysqldump_path' => 'Path of Executable',
    'mysqldump_options' => 'MySQL Dump Options',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Stile',
    'doctype' => 'Declarazione DOCTYPE',
    'menu_elements' => 'Elementi del Menu',
    'path_themes' => 'Percorse dei Stili',
    'disable_new_user_registration' => 'Disabilita Nuove Registrazioni',
    'allow_user_themes' => 'Permetti Stili Personali',
    'allow_user_language' => 'Permetti Lingue Personali',
    'allow_user_photo' => 'Permetti Foto Personali',
    'allow_username_change' => 'Permetti Cambiamenti del Nome Utente',
    'allow_account_delete' => 'Permetti Eliminazione Account',
    'hide_author_exclusion' => 'Permetti di Nascondere l\'Autore',
    'show_fullname' => 'Mostra intero Nome',
    'show_servicename' => 'Mostra il nome del Servizio',
    'custom_registration' => 'Permetti Registrazione Personalizzata',
    'user_login_method' => 'Metodo di Accesso per Utenti',
    'spamx' => 'Azioni Spam-X',
    'sort_admin' => 'Ordina Collegamenti',
    'language' => 'Lingua',
    'locale' => 'Localizzazione',
    'date' => 'Formato Data',
    'daytime' => 'Formato per il Tempo',
    'shortdate' => 'Formato per Data Corta',
    'dateonly' => 'Formato per solo la Data',
    'timeonly' => 'Formato per solo il Tempo',
    'week_start' => 'Inizio settimana',
    'hour_mode' => 'Formato per l\'Orario',
    'thousand_separator' => 'Separatore per Migliaia',
    'decimal_separator' => 'Punto Decimale',
    'decimal_count' => 'Posti decimali',
    'language_files' => 'File Linguistici',
    'languages' => 'Lingue',
    'timezone' => 'Fuso Orario',
    'site_disabled_msg' => 'Messaggio or percorso URL se il sito disabilitato',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Nome del Cookie per la Sessione',
    'cookie_name' => 'Nome del Cookie Permanente',
    'cookie_password' => 'Nome del Cookie per la Password',
    'cookie_theme' => 'Nome del Cookie per lo Stile',
    'cookie_language' => 'Nome del Cookie per la Lingua',
    'cookie_tzid' => 'Nome del Cookie per il Fuso Orario',
    'cookie_anon_name' => 'Nome del Cookie per il Nome Utente Anonimo',
    'cookie_ip' => 'Salvare IP nel Cookie?',
    'default_perm_cookie_timeout' => 'Scadenza Permanente',
    'session_cookie_timeout' => 'Scadenza Sessione',
    'cookie_path' => 'Percorso per i Cookie',
    'cookiedomain' => 'Dominio dei Cookie',
    'cookiesecure' => 'Sicurezza dei Cookie',
    'lastlogin' => 'Registrare Ultimo Login?',
    'num_search_results' => 'Numbero di Risultati per Ricerca',
    'loginrequired' => 'Login Necessario?',
    'submitloginrequired' => 'Login Necessario per Inviare?',
    'commentsloginrequired' => 'Login Necessario per Commenti?',
    'statsloginrequired' => 'Login Necessario per Statistiche?',
    'searchloginrequired' => 'Login Necessario per Ricerca?',
    'profileloginrequired' => 'Login Necessario per consultare Profili',
    'emailuserloginrequired' => 'Login Necessario per inviare E-Mail ad utenti?',
    'emailstoryloginrequired' => 'Login Necessario per inviare articolo via E-Mail?',
    'directoryloginrequired' => 'Login Necessario per la Directory?',
    'storysubmission' => 'Metti Articoli in Coda?',
    'usersubmission' => 'Metti Inserimenti in Coda?',
    'listdraftstories' => 'Mostra Bozze di Articoli?',
    'notification' => 'Notificazioni',
    'postmode' => 'Modo di Pubblicazione Predefinito',
    'speedlimit' => 'Limite di velocita per Pubblicazioni',
    'skip_preview' => 'Salta Anteprima in pubblicazioni',
    'advanced_editor' => 'Editor Avanzato?',
    'wikitext_editor' => 'Editor Wikitext?',
    'cron_schedule_interval' => 'Intervallo per Cron',
    'sortmethod' => 'Ordina Argomenti',
    'showstorycount' => 'Mostra Numero di Articoli?',
    'showsubmissioncount' => 'Mostra Nuomero di Inserimenti?',
    'hide_home_link' => 'Mostra il Collegamento per Home?',
    'whosonline_threshold' => 'Scadenza della Sessione',
    'whosonline_anonymous' => 'Nascondere Nomi dagli Utenti Anonimi?',
    'emailstories' => 'Attivare Daily Digest?',
    'emailstorieslength' => 'Lunghezza degli Articoli',
    'emailstoriesperdefault' => 'Abilitare per Nuovi Utenti?',
    'allow_domains' => 'Permetti Domini Autometicamente',
    'disallow_domains' => 'Rifiuta Domini Autometicamente',
    'newstoriesinterval' => 'Intervallo tra Nuovi Articoli',
    'newcommentsinterval' => 'Intervallo tra Nuovi Commenti',
    'newtrackbackinterval' => 'Intervallo per Nuovi Trackback',
    'hidenewstories' => 'Nascondi Nuove Storie',
    'hidenewcomments' => 'Nascondi Nuovi Commenti',
    'hidenewtrackbacks' => 'Nascondi Nuovi Trackback',
    'hidenewplugins' => 'Nascondi gli Inserimenti dei Nuovi Plug-in',
    'title_trim_length' => 'Limita Lunghezza del Titolo',
    'trackback_enabled' => 'Trackback Abilitato?',
    'pingback_enabled' => 'Pingback Abilitato?',
    'ping_enabled' => 'Ping Abilitato?',
    'trackback_code' => 'Trackback Predefinito',
    'multiple_trackbacks' => 'Trackback Multipli',
    'trackbackspeedlimit' => 'Limite di Velocitá per Trackback',
    'check_trackback_link' => 'Controlla Trackbacks',
    'pingback_self' => 'Inviare Pingback a Sé Stesso?',
    'pingback_excerpt' => 'Creare Pingback Excerpt?',
    'link_documentation' => 'Collegamento alla Documentazione?',
    'link_versionchecker' => 'Collegamento per Controllare la Versione?',
    'maximagesperarticle' => 'Massimo Numero di Immagini per Articolo',
    'limitnews' => 'Articoli per Pagina',
    'minnews' => 'Min. Articoli per Pagina',
    'contributedbyline' => 'Mostrare "Inviato da"?"',
    'hideviewscount' => 'Nascondere Contatore di Visite?',
    'hideemailicon' => 'Nascondere l\'icona della E-Mail?',
    'hideprintericon' => 'Nascondere l\'icona di Stampa?',
    'allow_page_breaks' => 'Allow Page Breaks?',
    'page_break_comments' => 'Commenti su Articoli di Multiple Pagine',
    'article_image_align' => 'Allineamento per Icone degli Articoli',
    'show_topic_icon' => 'Mostrare L\'Icone per Articoli?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Copertina Predefinita',
    'hide_no_news_msg' => 'Mascondere il Messaggio "Niente Notizie"?',
    'hide_main_page_navigation' => 'Nascondere La Navigazione sulla Pagina Principale?',
    'onlyrootfeatures' => 'Solo Root puó metter "In Vetrina"',
    'aftersave_story' => 'Dopo Aver Salvato l\'Articolo',
    'aftersave_user' => 'Dopo Aver Salvato l\'Utente',
    'show_right_blocks' => 'Mostrare Sempre I blocchi a Destra?',
    'showfirstasfeatured' => 'Mostrare il Primo Articolo come "In Vetrina"?',
    'backend' => 'Abilitare Flussi?',
    'rdf_file' => 'Cartella di Uscita Syndication',
    'rdf_limit' => 'Limite per Flussi',
    'rdf_storytext' => 'Lunghezza di articoli nei Flussi',
    'rdf_language' => 'Lingua dei Flussi',
    'syndication_max_headlines' => 'Massimo Numero di Titoli (portal blocks)',
    'copyrightyear' => 'Copyright Anno',
    'image_lib' => 'Libreria d\'Immagini',
    'path_to_mogrify' => 'Percorso per Mogrify',
    'path_to_netpbm' => 'Percorso per Netpbm',
    'debug_image_upload' => 'Debug per Caricamento Immagini?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Permetti Ridimensionamento dagli Utenti?',
    'jpeg_quality' => 'Qualitá JPEG?',
    'max_image_width' => 'Massima Larghezza per Immagini?',
    'max_image_height' => 'Massima Altezza per Immagini?',
    'max_image_size' => 'Massima Dimensione per Immagini?',
    'max_topicicon_width' => 'Massima Larghezza per le icone per Articoli?',
    'max_topicicon_height' => 'Massima Altezza per le icone per Articoli?',
    'max_topicicon_size' => 'Massima Dimensione per le icone per Articoli?',
    'max_photo_width' => 'Massima Larghezza per le Foto?',
    'max_photo_height' => 'Massima Altezza per le Foto?',
    'max_photo_size' => 'Massima Dimensione per le Foto?',
    'use_gravatar' => 'Utilizzare Gravatar?',
    'gravatar_rating' => 'Rating per Gravatar',
    'force_photo_width' => 'Imponi Larghezza Foto',
    'default_photo' => 'Foto Predefinita',
    'commentspeedlimit' => 'Limite Velocitá per Commenti',
    'comment_limit' => 'Limite di Commenti',
    'comment_mode' => 'Modo per Commenti',
    'comment_code' => 'Predefinito per Commenti',
    'comment_edit' => 'Permettere Modifica dei Commenti?',
    'comment_edittime' => 'Tempo per Modifica dei Commenti (secondi)',
    'commentsubmission' => 'Metti Inserimenti dei Commenti in Coda',
    'passwordspeedlimit' => 'Limite di velocitá per password',
    'login_attempts' => 'Massimo Numero di Tentativi di Accesso',
    'login_speedlimit' => 'Limite di Velocitá di Accesso ',
    'user_html' => 'HTML per Utenti',
    'admin_html' => 'HTML per Ammin',
    'advanced_html' => 'Extra HTML per l\'Editor Avanzato',
    'skip_html_filter_for_root' => 'Nessun filtro HTML per l\'utente Root?',
    'allowed_protocols' => 'Protocolli Permessi',
    'disable_autolinks' => 'Disbilitare gli Autotag?',
    'clickable_links' => 'Permetti di Cliccare su Collegamenti?',
    'compressed_output' => 'Inviare i dati in Formato Compresso?',
    'frame_options' => 'Protezione contro "clickjacking"',
    'censormode' => 'Attivare Modo Censurato?',
    'censorreplace' => 'Sostituire Il Testo Censurato Con',
    'censorlist' => 'Lista di Parole Censurate',
    'ip_lookup' => 'Risoluzione IP',
    'url_rewrite' => 'Abilitare il Riscrivemento di Percorsi (URL Rewrite)',
    'meta_tags' => 'Meta Tag',
    'meta_description' => 'Meta Description Predefinito',
    'meta_keywords' => 'Meta Keywords Predefinito',
    'default_permissions_block' => 'Permessi Predefiniti per Blocchi',
    'default_permissions_story' => 'Permessi Predefiniti per Articoli',
    'default_permissions_topic' => 'Permessi Predefiniti per Argomenti',
    'atom_max_stories' => 'Massimo Numero di Articoli Disponibili negli Flussi dei Servizi Web',
    'disable_webservices' => 'Disabilitare Servizi Web?',
    'restrict_webservices' => 'Limitare Servizi Web?',
    'article_comment_close_enabled' => 'Automaticamente chiudere i commenti (predefinito)',
    'article_comment_close_days' => 'Disabilitare Commenti Dopo Numero di Giorni(predefinito)',
    'comment_close_rec_stories' => 'Numero di articoli nuovi da abilitare per i commenti',
    'allow_reply_notifications' => 'Permetti di Notificare di Nuovi Commenti?',
    'search_style' => 'Stile dei Risultati della Ricerca',
    'search_limits' => 'Limiti delle Pagine',
    'search_show_num' => 'Mostrare il Numero del Risultato?',
    'search_show_type' => 'Mostrare il Tipo del Risultato?',
    'search_show_sort' => 'Permettere agli Utenti di Ordinare i Risultati?',
    'search_show_limit' => 'Mostrare Limiti delle Pagine?',
    'search_separator' => 'Separatore di Gruppi',
    'search_def_keytype' => 'Metodo di Ricerca Predefinito',
    'search_def_sort' => 'Ordine Predefinito'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Sito',
    'sg_stories' => 'Articoli e Trackback',
    'sg_theme' => 'Stili',
    'sg_blocks' => 'Blocchi',
    'sg_users' => 'Utenti ed Inserimenti',
    'sg_images' => 'Immagini',
    'sg_locale' => 'Langue e Localizzazioni',
    'sg_misc' => 'Varie'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Sito',
    'fs_paths' => 'Percorsi',
    'fs_theme' => 'Stile',
    'fs_mail' => 'Mail',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Utenti',
    'fs_misc' => 'Varie',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Blocco Ammin',
    'fs_locale' => 'Localizzazione',
    'fs_language' => 'Lingua',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Cookie',
    'fs_login' => 'Impostazioni di Accesso',
    'fs_search' => 'Ricerca',
    'fs_user_submission' => 'Inserimenti da Utenti',
    'fs_submission' => 'Impostazioni di Inserimenti',
    'fs_topics_block' => 'Blocco di Argomenti',
    'fs_whosonline_block' => 'Blocco di chi é in Linea',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'Blocco per Novitá',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Articolo',
    'fs_theme_advanced' => 'Impostazioni Avanzate',
    'fs_syndication' => 'Pubblicazione',
    'fs_imagelib' => 'Libreria d\'Immagini',
    'fs_upload' => 'Carica',
    'fs_articleimg' => 'Immagini negli Articoli',
    'fs_topicicon' => 'Icone nell\'Argomento',
    'fs_userphoto' => 'Foto',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Commenti',
    'fs_htmlfilter' => 'Filtro HTML',
    'fs_censoring' => 'Censura',
    'fs_iplookup' => 'IP Lookup',
    'fs_perm_story' => 'Permessi Predefiniti per Articoli',
    'fs_perm_topic' => 'Permessi Predefiniti per Argomenti',
    'fs_perm_block' => 'Permessi Predefiniti per Blocco',
    'fs_webservices' => 'Servizi Web'
);

$LANG_configselects['Core'] = array(
    0 => array('Vero' => 1, 'Falso' => 0),
    1 => array('Vero' => true, 'Falso' => false),
    2 => array('Non accettare' => 0, 'Salva solo gli ultimi' => 1, 'Permetti Multipli Inserimenti' => 2),
    3 => array('Trackback Abilitato' => 0, 'Trackback Disabilitato' => -1),
    4 => array('Non controllare nulla' => 0, 'Confronta con l\'indirizzo del sito' => 1, 'Confronta con l\'intero indirizzo' => 2, 'Confronta con Entrambi' => 3, 'Confronta IP con IP del sito' => 4, 'Confronta IP con l\'indirizzo del sito' => 5, 'Controlla IP e l\'intero indirizzo' => 6, 'Controlla IP, l\'intero indirizzo, e l\'indirizzo del sito' => 7),
    5 => array('Testo non formattato' => 'plaintext', 'Testo in formato HTML' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Ultima Pagina' => 'last', 'Prima Pagina' => 'first', 'Ogni Pagina' => 'all'),
    8 => array('Destra' => 'right', 'Sinistra' => 'left'),
    9 => array('Vai a pagina' => 'item', 'Mostra Lista' => 'list', 'Mostra Home' => 'home', 'Mostra Admin' => 'admin'),
    10 => array('Nessuna' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Flat' => 'flat', 'Nested' => 'nested', 'Threaded' => 'threaded', 'No Comments' => 'nocomment'),
    12 => array('Nessun Accesso' => 0, 'Sola lettura' => 2, 'Lettura e Scrittura' => 3),
    13 => array('Ignora' => 0, 'Permetti, con il limite di Velocitá' => 1, 'Permetti, senza il limite di Velocitá' => 2),
    14 => array('Domenica' => 'Sun', 'Lunedí' => 'Mon'),
    15 => array('Numbericamente' => 'sortnum', 'Alfabeticamente' => 'alpha'),
    16 => array('No' => 0, 'Solo per la ricerca avanzata' => 1, 'Per la ricerca semplice ed avanzata' => 2),
    17 => array('Commenti Abilitati' => 0, 'Commenti Disabilitati' => -1),
    18 => array('No' => 0, 'Si (Corrispondenza Esatta)' => 1, 'Si (Inizio Parola)' => 2, 'Si (Fragmento della Parola)' => 3),
    19 => array('Google' => 'google', 'Tabella' => 'table'),
    20 => array('Frase Esatta' => 'phrase', 'Tutte le Parole' => 'all', 'Qualsiasi Parola' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Elevata' => 'DENY', 'Stessa Origine' => 'SAMEORIGIN', '(disabilitata)' => ''),
    23 => array('Disabilitati' => 0, 'Abilitati' => 1, 'Abilitati (Predefiniti solo per la homepage)' => 2),
    24 => array('Contribuisci' => 'contribute', 'Home' => 'home', 'Ricerca Avanzata' => 'search', 'Directory' => 'directory', 'Il Mio Account' => 'prefs', 'Inserimenti di Plug-in' => 'plugins', 'Inserimenti personalizzati' => 'custom', 'Statistiche del Sito' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Visite (asc)' => 'hits|asc', 'Visite (desc)' => 'hits|desc', 'Data (asc)' => 'date|asc', 'Data (desc)' => 'date|desc', 'Titolo (asc)' => 'title|asc', 'Titolo (desc)' => 'title|desc', 'Autore (asc)' => 'uid|asc', 'Autore (desc)' => 'uid|desc')
);

?>
